
.. image:: https://readthedocs.org/projects/aws-dynamodb-io/badge/?version=latest
    :target: https://aws-dynamodb-io.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/aws_dynamodb_io-project/actions/workflows/main.yml/badge.svg
    :target: https://github.com/MacHu-GWU/aws_dynamodb_io-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/aws_dynamodb_io-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/aws_dynamodb_io-project

.. image:: https://img.shields.io/pypi/v/aws-dynamodb-io.svg
    :target: https://pypi.python.org/pypi/aws-dynamodb-io

.. image:: https://img.shields.io/pypi/l/aws-dynamodb-io.svg
    :target: https://pypi.python.org/pypi/aws-dynamodb-io

.. image:: https://img.shields.io/pypi/pyversions/aws-dynamodb-io.svg
    :target: https://pypi.python.org/pypi/aws-dynamodb-io

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_dynamodb_io-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_dynamodb_io-project

------

.. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://aws-dynamodb-io.readthedocs.io/en/latest/

.. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://aws-dynamodb-io.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/aws_dynamodb_io-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/aws_dynamodb_io-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/aws_dynamodb_io-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/aws-dynamodb-io#files


Welcome to ``aws_dynamodb_io`` Documentation
==============================================================================
.. image:: https://aws-dynamodb-io.readthedocs.io/en/latest/_static/aws_dynamodb_io-logo.png
    :target: https://aws-dynamodb-io.readthedocs.io/en/latest/

See examples:

- `export_table.py <https://github.com/MacHu-GWU/aws_dynamodb_io-project/blob/main/examples/export_table.py>`_
- `import_table.py <https://github.com/MacHu-GWU/aws_dynamodb_io-project/blob/main/examples/import_table.py>`_


.. _install:

Install
------------------------------------------------------------------------------

``aws_dynamodb_io`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install aws-dynamodb-io

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade aws-dynamodb-io
